@@ -14,12 +14,10 @@ from dbt.adapters.base import Credentials
 from dbt.adapters.sql import SQLConnectionManager
 from dbt.contracts.connection import AdapterResponse
 from dbt.events import AdapterLogger
-from dbt.exceptions import DatabaseException, FailedToConnectException, RuntimeException
+from dbt.exceptions import DbtDatabaseError, DbtRuntimeError, FailedToConnectError
 from dbt.helper_types import Port
 from trino.transaction import IsolationLevel
 
-from dbt.adapters.trino.__version__ import version
-
 logger = AdapterLogger("Trino")
 PREPARED_STATEMENTS_ENABLED_DEFAULT = True
 
@@ -103,6 +101,7 @@ class TrinoNoneCredentials(TrinoCredentials):
     session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
     retries: Optional[int] = trino.constants.DEFAULT_MAX_ATTEMPTS
+    timezone: Optional[str] = None
 
     @property
     def method(self):
@@ -126,6 +125,7 @@ class TrinoCertificateCredentials(TrinoCredentials):
     session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
     retries: Optional[int] = trino.constants.DEFAULT_MAX_ATTEMPTS
+    timezone: Optional[str] = None
 
     @property
     def http_scheme(self):
@@ -155,6 +155,7 @@ class TrinoLdapCredentials(TrinoCredentials):
     session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
     retries: Optional[int] = trino.constants.DEFAULT_MAX_ATTEMPTS
+    timezone: Optional[str] = None
 
     @property
     def http_scheme(self):
@@ -189,6 +190,7 @@ class TrinoKerberosCredentials(TrinoCredentials):
     session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
     retries: Optional[int] = trino.constants.DEFAULT_MAX_ATTEMPTS
+    timezone: Optional[str] = None
 
     @property
     def http_scheme(self):
@@ -226,6 +228,7 @@ class TrinoJwtCredentials(TrinoCredentials):
     session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
     retries: Optional[int] = trino.constants.DEFAULT_MAX_ATTEMPTS
+    timezone: Optional[str] = None
 
     @property
     def http_scheme(self):
@@ -251,6 +254,7 @@ class TrinoOauthCredentials(TrinoCredentials):
     session_properties: Dict[str, Any] = field(default_factory=dict)
     prepared_statements_enabled: bool = PREPARED_STATEMENTS_ENABLED_DEFAULT
     retries: Optional[int] = trino.constants.DEFAULT_MAX_ATTEMPTS
+    timezone: Optional[str] = None
     OAUTH = trino.auth.OAuth2Authentication(
         redirect_auth_url_handler=trino.auth.WebBrowserRedirectHandler()
     )
@@ -378,21 +382,21 @@ class TrinoConnectionManager(SQLConnectionManager):
             msg = str(e)
 
             if "Failed to establish a new connection" in msg:
-                raise FailedToConnectException(msg) from e
+                raise FailedToConnectError(msg) from e
 
             if isinstance(e, trino.exceptions.TrinoQueryError):
                 logger.debug("Trino query id: {}".format(e.query_id))
             logger.debug("Trino error: {}".format(msg))
 
-            raise DatabaseException(msg)
+            raise DbtDatabaseError(msg)
         except Exception as e:
             msg = str(e)
-            if isinstance(e, RuntimeException):
+            if isinstance(e, DbtRuntimeError):
                 # during a sql query, an internal to dbt exception was raised.
                 # this sounds a lot like a signal handler and probably has
                 # useful information, so raise it without modification.
                 raise
-            raise RuntimeException(msg) from e
+            raise DbtRuntimeError(msg) from e
 
     # For connection in auto-commit mode there is no need to start
     # separate transaction. If using auto-commit, the client will
@@ -429,8 +433,9 @@ class TrinoConnectionManager(SQLConnectionManager):
             auth=credentials.trino_auth(),
             max_attempts=credentials.retries,
             isolation_level=IsolationLevel.AUTOCOMMIT,
-            source=f"dbt-trino-{version}",
+            source="dbt-trino",
             verify=credentials.cert,
+            timezone=credentials.timezone,
         )
         connection.state = "open"
         connection.handle = ConnectionWrapper(trino_conn, credentials.prepared_statements_enabled)
@@ -477,7 +482,7 @@ class TrinoConnectionManager(SQLConnectionManager):
             else:
                 conn_name = conn.name
 
-            raise RuntimeException(
+            raise DbtRuntimeError(
                 "Tried to run an empty query on model '{}'. If you are "
                 "conditionally running\nsql, eg. in a model hook, make "
                 "sure your `else` clause contains valid sql!\n\n"
